summaryrefslogtreecommitdiffstats
path: root/kmail/bodyvisitor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/bodyvisitor.cpp')
-rw-r--r--kmail/bodyvisitor.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/bodyvisitor.cpp b/kmail/bodyvisitor.cpp
index 8a40d744..04b7a98b 100644
--- a/kmail/bodyvisitor.cpp
+++ b/kmail/bodyvisitor.cpp
@@ -76,9 +76,9 @@ namespace KMail {
while ( (part = it.current()) != 0 )
{
++it;
- // skip this part if the tqparent part is already loading
- if ( part->tqparent() &&
- selected.contains( part->tqparent() ) &&
+ // skip this part if the parent part is already loading
+ if ( part->parent() &&
+ selected.contains( part->parent() ) &&
part->loadPart() )
continue;
@@ -114,7 +114,7 @@ namespace KMail {
headerCheck = false;
// check whether to load this part or not:
// look at the basic list, ask the subclass and check the tqparent
if ( mBasicList.contains( part->originalContentTypeStr() ) ||
parentNeedsLoading( part ) ||
addPartToList( part ) )
@@ -142,13 +142,13 @@ namespace KMail {
KMMessagePart *part = msgPart;
while ( part )
{
- if ( part->tqparent() &&
- ( part->tqparent()->originalContentTypeStr() == "MULTIPART/SIGNED" ||
+ if ( part->parent() &&
+ ( part->parent()->originalContentTypeStr() == "MULTIPART/SIGNED" ||
( msgPart->originalContentTypeStr() == "APPLICATION/OCTET-STREAM" &&
- part->tqparent()->originalContentTypeStr() == "MULTIPART/ENCRYPTED" ) ) )
+ part->parent()->originalContentTypeStr() == "MULTIPART/ENCRYPTED" ) ) )
return true;
- part = part->tqparent();
+ part = part->parent();
}
return false;
}
@@ -114,7 +114,7 @@ namespace KMail {
headerCheck = false;
// check whether to load this part or not:
- // look at the basic list, ask the subclass and check the tqparent
+ // look at the basic list, ask the subclass and check the parent
if ( mBasicList.contains( part->originalContentTypeStr() ) ||
parentNeedsLoading( part ) ||